---
title: "1. Storytelling with data"
description: |
  Example code used in class discussion.
output:
  distill::distill_article:
    toc: true
    toc_depth: 1
---

```{r setup, include=FALSE}
library(knitr)
opts_chunk$set(
  echo = TRUE,
  warning = FALSE,
  error = FALSE,
  message = FALSE,
  cache.extra = rand_seed
  )
```

[Here is this code's rmd file.](spencer-storytelling-01-code.rmd)

# Slide 38

In R, load libraries,

```{r}
library(tidyverse)
```

# Slide 39

then import data:

```{r}
df_r <- read_csv("data/201901-citibike-tripdata.csv")
```

Let's look at the beginning of the dataframe:

```{r}
df_r %>% glimpse() 
```

In Python, load libraries,

```{python echo=TRUE, results='hide' }
import pandas as pd
from plotnine import *
from datar.all import *
from pipda import options
options.assume_all_piping = True
```

then load our data: 

```{python}
df_py = pd.read_csv("data/201901-citibike-tripdata.csv")
```

As with R, let's get some information on the data frame:

```{python}
df_py.info()
```

# Slide 40

In R, let's create a new variable that flags whether the bike was rebalanced.

```{r}
df_r <- df_r %>% rename_all(function(x) gsub(" ", "_", x))


df_r <- df_r %>%
  filter(!is.na(start_station_id)) %>%
  arrange(starttime) %>%
  group_by(bikeid) %>%
  mutate(
    rebalanced = 
      if_else(row_number() > 1 & 
             start_station_id != lag(end_station_id),
             TRUE, FALSE)
  ) %>%
  ungroup()


df_r %>% pull(rebalanced) %>% table()
```

In Python,

```{python}
df_py = df_py.rename(lambda x: x.replace(' ', '_'), axis = 1)


df_py = df_py >> \
  filter( f.start_station_id.notnull() ) >> \
  arrange(f.starttime) >> \
  group_by(f.bikeid) >> \
  mutate(
    rebalanced = if_else(
      (row_number() > 1) and 
      (f.start_station_id != lag(f.end_station_id)), 
      TRUE, FALSE) ) >> \
  ungroup()


df_py.rebalanced.value_counts()
```

# Slide 41

In R,

```{r}
ggplot(data = df_r) + 
  geom_bar(
    mapping = aes(x = rebalanced), 
    stat = 'count'
  )
```

In Python,

```{python}
ggplot(df_py) + \
geom_bar(
    mapping = aes(x = 'rebalanced'), 
    stat = 'count'
  )
```

